/*************************************************************************
* COPYRIGHT (C) 1999 - 2007  EDF R&D, CEA/DEN
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


#include <med.h>
#include <med_config.h>
#include <med_outils.h>
#include <hdf5.h>

/*
 * - Nom de la fonction : _MEDdatagroupLienCreer
 * - Description : cration d'un lien SOFT HDF dans un datagroup
 * - Parametres :
 *     - id       (IN)    : l'ID du datagroup
 *     - nom      (IN)    : nom de l'objet source
 *     - nom_lien (IN)    : nom du lien a creer 
 * - Resultat : 0 en cas de succes, -1 sinon
 */ 

med_err 
_MEDdatagroupLienCreer(med_idt id,const char *nom, const char *nom_lien)
{
  med_err ret;

  if( (ret = H5Glink(id,H5G_LINK_SOFT,nom,nom_lien)) < 0 ) {
    MESSAGE("Impossible de crer le lien : ");
    SSCRUTE(nom_lien);
  }
  
  return ret;
}
